@@ -22,3 +22,9 @@ def import_path(path):
     modpath, cls = path.rsplit('.', 1)
     mod = __import__(modpath, globals(), locals(), ['xxx'])
     return getattr(mod, cls)
+
+
+def get_redirect_url(request, default_url):
+    "Extract saved redirect url or use default."
+
+    return request.session.get('xauth_redirect_url') or default_url
